==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/src/dialogs/e2_about_dialog.c <==
/* $Id: e2_about_dialog.c 975 2005-07-29 00:52:37Z tpgww $
 * 
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include <string.h>
#include "e2_dialog.h"
#include "e2_about_dialog.h"

static E2_Duo frees;

static void _e2_about_dialog_response_cb (GtkWidget *dialog,
	gint response, E2_Duo *frees)
{
	//cleanup the strings constructed when dialog set up
	g_free (frees->a);
	g_free (frees->b);
	gtk_widget_destroy (dialog);
}

static void _e2_about_dialog_view_cb (GtkWidget *widget,
	gchar *filepath)
{
	gchar *command = g_strconcat(_A(5),".",_A(75), NULL);	//file.view
	e2_action_run_simple (command, filepath);
	g_free (command);
}

static void _e2_about_dialog_view_cb2 (GtkWidget *widget,
	gchar *filepath)
{
	gchar *command = g_strconcat(_A(5),".",_A(76), NULL);	//file.view_at
	e2_action_run_simple (command, filepath);
	g_free (command);
}

static void _e2_about_dialog_setup_view (GtkWidget *box,
	gchar *helpfile, gboolean at)
{
	GtkWidget *hbox = e2_widget_add_box (box, FALSE,
		E2_PADDING_LARGE, FALSE, FALSE, 0);
	void *func = (at) ?
		_e2_about_dialog_view_cb2 : //open the helpfile at a specified string
		_e2_about_dialog_view_cb;	//just open the helpfile
	e2_button_add (hbox, FALSE, 0, _("_Read the file"),
		ICON_DIR"view_"E2IP".png", NULL, func, helpfile);
}

GtkWidget *_e2_about_dialog_create (void)
{
	gchar *icon_file = g_build_filename (ICON_DIR, BINNAME"_48.png", NULL);
	GtkWidget *dialog = e2_dialog_create (icon_file, 
		"<span size=\"x-large\" weight=\"bold\">" PROGNAME " " VERSION "</span>",
		_("help"), _e2_about_dialog_response_cb, &frees);
	g_free (icon_file);

	GtkWidget *notebook = e2_widget_add_notebook
		(GTK_DIALOG(dialog)->vbox, TRUE, 0, NULL, NULL);
	gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_LEFT);
	//info tab
	GtkWidget *vbox = e2_widget_add_notebook_page (dialog, notebook, _("about"));
	gchar *mesc = MESC (COPYRIGHT);
	gchar *message = g_strdup_printf
	(
		_("<b>A GTK+2 file manager</b>\n"
		"<b>implementing a two-pane design</b>\n\n"
		"Copyright (C) %s\n\n"   // \302\251 stuffs up gettext
		"This program is licensed under the terms of the General Public License "
		"and comes with ABSOLUTELY NO WARRANTY\n\n"
		"This binary was compiled on %s\n"
		"using %s and GTK+%d.%d.%d"),
		mesc, __DATE__, BUILDINFO,
		GTK_MAJOR_VERSION, GTK_MINOR_VERSION, GTK_MICRO_VERSION
	);
	g_free (mesc);
	GtkWidget *label = e2_widget_add_label (vbox, message, 0.5, FALSE, 0);
	g_free (message);
	gchar *fmsg = _("The file\n<b>%s</b>\ngives details.");
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
	//contribs tab
	vbox = e2_widget_add_notebook_page (dialog, notebook, _("contributors"));
	gchar *helpfile = DOC_DIR"CREDITS";
	gchar *message2 = g_strdup_printf (fmsg, helpfile, FALSE);
	message = g_strconcat (
	_("This program is based on emelFM, developed by Michael Clark.\n\n"
		"Contributions have been made by many friends. "),
		message2, NULL);
	label = e2_widget_add_label (vbox, message, 0.0, FALSE, 0);
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
	g_free (message2);
	g_free (message);
	_e2_about_dialog_setup_view (vbox, helpfile, FALSE);
	//usage tab
	gchar *title = _("usage");
	vbox = e2_widget_add_notebook_page (dialog, notebook, title);
//	helpfile = DOC_DIR MAIN_HELP;	//these are both strings
	helpfile = e2_option_str_get ("usage-help-doc");
	message = g_strdup_printf (fmsg, helpfile);
	label = e2_widget_add_label (vbox, message, 0.0, FALSE, 0);
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
//	g_free (message);
	frees.a = g_strconcat (helpfile," [",title,"]",NULL);	//remember, for cleanup when finished
	_e2_about_dialog_setup_view (vbox, (gchar *) frees.a, TRUE);
	//commands tab
	title = _("commands");
	vbox = e2_widget_add_notebook_page (dialog, notebook, title);
	label = e2_widget_add_label (vbox, message, 0.0, FALSE, 0);
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
	g_free (message);
	frees.b = g_strconcat (helpfile," [",title,"]",NULL); //remember, for cleanup when finished
	_e2_about_dialog_setup_view (vbox, (gchar *) frees.b, TRUE);

	return dialog;
}

void e2_about_dialog_open (void)
{
	GtkWidget *dialog = _e2_about_dialog_create ();
	e2_dialog_resize (dialog, 2.0);	//this won't increase size past the actual need
	e2_dialog_show (dialog, app.main_window, 0, &E2_BUTTON_CLOSE, NULL);
}

==> emelfm2-0.1.4.tar.gz: emelfm2-0.1.4/src/dialogs/e2_about_dialog.c <==
/* $Id: e2_about_dialog.c 1425 2005-12-03 02:22:50Z tpgww $
 * 
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include <string.h>
#include "e2_dialog.h"
#include "e2_about_dialog.h"

static E2_Duo frees;

static void _e2_about_dialog_response_cb (GtkWidget *dialog,
	gint response, E2_Duo *frees)
{
	//cleanup the strings constructed when dialog set up
	g_free (frees->a);
	g_free (frees->b);
	gtk_widget_destroy (dialog);
}

static void _e2_about_dialog_view_cb (GtkWidget *widget,
	gchar *filepath)
{
	gchar *command = g_strconcat(_A(5),".",_A(81), NULL);	//file.view
	e2_action_run_simple (command, filepath);
	g_free (command);
}

static void _e2_about_dialog_view_cb2 (GtkWidget *widget,
	gchar *filepath)
{
	gchar *command = g_strconcat(_A(5),".",_A(82), NULL);	//file.view_at
	e2_action_run_simple (command, filepath);
	g_free (command);
}

static void _e2_about_dialog_setup_view (GtkWidget *box,
	gchar *helpfile, gboolean at)
{
	GtkWidget *hbox = e2_widget_add_box (box, FALSE,
		E2_PADDING_LARGE, FALSE, FALSE, 0);
	void *func = (at) ?
		_e2_about_dialog_view_cb2 : //open the helpfile at a specified string
		_e2_about_dialog_view_cb;	//just open the helpfile
	e2_button_add (hbox, FALSE, 0, _("_Read the file"),
		"view_"E2IP".png", NULL, func, helpfile);
}

GtkWidget *_e2_about_dialog_create (void)
{
	gchar *iconsdir = e2_utils_get_icon_dir ();
	gchar *icon_file = g_build_filename (iconsdir, BINNAME"_48.png", NULL);
	GtkWidget *dialog = e2_dialog_create (icon_file, 
		"<span size=\"x-large\" weight=\"bold\">" PROGNAME " " VERSION "</span>",
		_("help"), _e2_about_dialog_response_cb, &frees);
	g_free (iconsdir);
	g_free (icon_file);

	GtkWidget *notebook = e2_widget_add_notebook
		(GTK_DIALOG(dialog)->vbox, TRUE, 0, NULL, NULL);
	gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_LEFT);
	//info tab
	GtkWidget *vbox = e2_widget_add_notebook_page (dialog, notebook, _("about"));
	gchar *mesc = MESC (COPYRIGHT);
	gchar *message = g_strdup_printf
	(
		_("<b>A GTK+2 file manager</b>\n"
		"<b>implementing a two-pane design</b>\n\n"
		"Copyright (C) %s\n\n"   // \302\251 stuffs up gettext
		"This program is licensed under the terms of the General Public License "
		"and comes with ABSOLUTELY NO WARRANTY\n\n"
		"This binary was compiled on %s\n"
		"using %s and GTK+%d.%d.%d"),
		mesc, __DATE__, BUILDINFO,
		GTK_MAJOR_VERSION, GTK_MINOR_VERSION, GTK_MICRO_VERSION
	);
	g_free (mesc);
	GtkWidget *label = e2_widget_add_label (vbox, message, 0.5, FALSE, 0);
	g_free (message);
	gchar *fmsg = _("The file\n<b>%s</b>\ngives details.");
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
	//contribs tab
	vbox = e2_widget_add_notebook_page (dialog, notebook, _("contributors"));
	gchar *helpfile = DOC_DIR"CREDITS";
	gchar *message2 = g_strdup_printf (fmsg, helpfile, FALSE);
	message = g_strconcat (
	_("This program is based on emelFM, developed by Michael Clark.\n\n"
		"Contributions have been made by many friends. "),
		message2, NULL);
	label = e2_widget_add_label (vbox, message, 0.0, FALSE, 0);
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
	g_free (message2);
	g_free (message);
	_e2_about_dialog_setup_view (vbox, helpfile, FALSE);
	//usage tab
	gchar *title = _("usage");
	vbox = e2_widget_add_notebook_page (dialog, notebook, title);
//	helpfile = DOC_DIR MAIN_HELP;	//these are both strings
	helpfile = e2_option_str_get ("usage-help-doc");
	message = g_strdup_printf (fmsg, helpfile);
	label = e2_widget_add_label (vbox, message, 0.0, FALSE, 0);
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
//	g_free (message);
	frees.a = g_strconcat (helpfile," [",title,"]",NULL);	//remember, for cleanup when finished
	_e2_about_dialog_setup_view (vbox, (gchar *) frees.a, TRUE);
	//commands tab
	title = _("commands");
	vbox = e2_widget_add_notebook_page (dialog, notebook, title);
	label = e2_widget_add_label (vbox, message, 0.0, FALSE, 0);
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
	g_free (message);
	frees.b = g_strconcat (helpfile," [",title,"]",NULL); //remember, for cleanup when finished
	_e2_about_dialog_setup_view (vbox, (gchar *) frees.b, TRUE);

	return dialog;
}

void e2_about_dialog_open (void)
{
	GtkWidget *dialog = _e2_about_dialog_create ();
	e2_dialog_resize (dialog, 2.0);	//this won't increase size past the actual need
	e2_dialog_show (dialog, app.main_window, 0, &E2_BUTTON_CLOSE, NULL);
}
